#
# spec file for package webcamoid
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           webcamoid
Version:        8.1.0
Release:        8.2
Summary:        Webcam plasmoid for KDE
License:        GPL-3.0-or-later
Group:          System/GUI/KDE
Url:            https://webcamoid.github.io/
Source:         https://github.com/hipersayanX/Webcamoid/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM webcamoid-8.1.0-ffmpeg4.patch
Patch0:         webcamoid-8.1.0-ffmpeg4.patch
BuildRequires:  bison
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  kf5-filesystem
BuildRequires:  libqt5-linguist
BuildRequires:  perl-Text-Markdown
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.6
BuildRequires:  pkgconfig(Qt5OpenGL) >= 5.6
BuildRequires:  pkgconfig(Qt5Qml) >= 5.6
BuildRequires:  pkgconfig(Qt5Quick) >= 5.6
BuildRequires:  pkgconfig(Qt5Svg) >= 5.6
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.6
BuildRequires:  pkgconfig(frei0r)
BuildRequires:  pkgconfig(libavcodec) >= 58.7.100
BuildRequires:  pkgconfig(libavdevice) >= 57.0.0
BuildRequires:  pkgconfig(libavformat) >= 58.0.102
BuildRequires:  pkgconfig(libavutil) >= 56.6.100
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libswscale) >= 5.0.101
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(qimageblitz)
Requires:       frei0r-plugins
Requires:       frei0r-plugins-opencv
Provides:       plasmoid-webcamoid = %{version}
Obsoletes:      plasmoid-webcamoid < %{version}

%description
Webcam plasmoid for KDE desktop environment.

Features:
* Take pictures with the webcam.
* Record videos.
* Manages multiple webcams.
* Play/Stop capture, this saves resources while the plasmoid is not in use.
* Written in C++.
* 100% Qt based software, for KDE/Qt purists.
* Custom controls for each webcam.
* Popup applet support (you can embed Webcamoid in the panel).
* Add funny effects to the webcam (requires Frei0r plugins and QImageBlitz).
* +50 effects available.
* Effects with live previews.
* Translated to many languages.
* Stand alone installation mode (use it as a normal program).
* Use custom network and local files as capture devices.
* Capture from desktop.

%package devel
Summary:        Development headers and libraries for Webcamoid
Group:          Development/Libraries/C and C++
Requires:       plasmoid-webcamoid = %{version}

%description devel
Development headers and libraries for Webcamoid.
Avkys library provides a wide range of plugins for audio and
video playing, recording, capture, and processing.

%prep
%setup -q -n webcamoid-%{version}
%patch0 -p1

%build
qmake-qt5 \
    Webcamoid.pro \
    LIBDIR=%{_libdir} \
    USE3DPARTYLIBS=0 \
    LICENSEDIR=%{_defaultdocdir}/webcamoid \
    INSTALLDEVHEADERS=1 \
    QMAKE_LRELEASE=%{_bindir}/lrelease-qt5 \
    INSTALLQMLDIR=%{_kf5_qmldir}

make %{?_smp_mflags}

# generate help file
Markdown.pl --html4 README.md > README.html

%install
make INSTALL_ROOT=%{buildroot} install

%{kf5_post_install}

%fdupes %{buildroot}%{_datadir}

desktop-file-edit %{buildroot}%{_kf5_applicationsdir}/webcamoid.desktop --remove-category=KDE --add-category=Video --add-category=Player

rm -rf %{buildroot}%{_datadir}/licenses/
rm -rf %{buildroot}%{_datadir}/doc/

%post
/sbin/ldconfig
%icon_theme_cache_post
%desktop_database_post

%postun
/sbin/ldconfig
%icon_theme_cache_postun
%desktop_database_postun

%files
%doc AUTHORS ChangeLog README.html THANKS
%license COPYING
%{_bindir}/webcamoid
%{_kf5_applicationsdir}/webcamoid.desktop
%{_libdir}/libavkys.so.*
%{_libdir}/avkys
%{_libdir}/avkys/*.so
%{_kf5_qmldir}/AkQml
%{_kf5_qmldir}/AkQml/libAkQml.so
%{_kf5_qmldir}/AkQml/qmldir
%{_kf5_mandir}/man1/webcamoid.1.gz
%{_kf5_iconsdir}/hicolor

%files devel
%{_libdir}/libavkys.so
%{_includedir}/avkys
%{_includedir}/avkys/*.h

%changelog
* Sun Jul  8 2018 aloisio@gmx.com
- Added webcamoid-8.1.0-ffmpeg4.patch to support ffmpeg4 and
  changed requirements accordingly
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Wed Dec 13 2017 aloisio@gmx.com
- Added frei0r-plugins-opencv as runtime requirement to account
  for (boo#1068792)
* Tue Oct 10 2017 aloisio@gmx.com
- Update to version 8.1.0
  * Improved startup time.
  * Deadlock when audio recording is enabled my be solved now.
    Audio recording enabled by default again.
  * Hopefully, fixed many segfaults in many platforms.
- Dropped webcamoid-fix_man.patch (merged upstream)
* Sat Jun 17 2017 aloisio@gmx.com
- Update to version 8.0.0
  * Added support for Mac and FreeBSD (virtual camera is not
    supported  * yet).
  * Added new masks to the FaceDetect plugin.
  * Now is possible to Switch between FFmpeg and GStreamer on
    runtime.
  * Added support for ALSA, OSS, JACK and QAudio.
  * Added support for libuvc.
  * Now is possible to select the desired input and output device,
    and  * configure playback and capture formats.
  * More translations updates.
  * Added options for configuring plugins search paths and
    blacklist  * in GUI.
  * Added options for configuring the desired frameworks and
    libraries.
  * Added formats and codecs config in recording options.
  * FFmpeg >= 3.1 required.
  * Added support for MSVC2013 and MSVC2015 build.
  * Added option for configure FPS in DesktopCapture plugin.
  * Added updates options.
  * AppImage support.
- Added webcamoid-fix_man.patch to address build problem on
  Tumbleweed
* Fri May 12 2017 aloisio@gmx.com
- Update to version 7.2.1
  * Added alternative root method (VirtualCamera). See ROOT_METHOD
    on project wiki.
  * C++11 support enabled by default.
  * Using new algorithm for Cartoon plugin.
  version 7.2.0:
  * Fixed problems when recording.
  * Added timer and flash when taking photos.
  * Better virtual camera management.
  * Added Virtual camera support for Windows.
  * Added GIF recording support (FFmpeg only).
  * Improved webcam format selection.
  * UI improvements.
  * Added play on start option.
  * Added C++11 support for Clang build.
- Renamed package to webcamoid
* Fri Apr 29 2016 aloisio@gmx.com
- Update to version 7.1.0
  * Reworked audio system.
  * Added support for compressed formats in webcams.
  * No more lags in the UI when capturing from webcam.
  * Added Windows installer.
  7.0.0:
  * Windows port finally working! EXPERIMENTAL!
  * Reworked recording options. More user friendly.
  * Removed unnecessary dependencies.
  * Many effects reworked and bugfixed.
  * Added GStreamer support, EXPERIMENTAL!
  * Fixed SEGFAULT when switching the effects.
  * Added virtual camera support (GNU/Linux only).
  * Added command line options for controlling plugins search.
  6.2.0:
  * Reworked Cartoonify plugin.
  * Some improvements in FaceDetect plugin.
  * Added Canny mode for Edge detection plugin.
  * Improved Blur and Denoise plugins.
  * Fixed QDataStream missing header.
  6.1.0:
  * Removed OpenCV as dependency (yes, again).
  * Fixed Denoise plugin SEGFAULT.
  * Translations updated.
  6.0.0:
  * New Qml UI, more user friendly.
  * Now, the effects can be customized.
  * A lot of bug fixes.
  5.1.0:
  * From now on, Webcamoid will be developed using Qt5.
  * Removed Frei0r from dependencies.
  * Added OpenCV as dependency (Face detection).
  * Removed plasmoid build since Qt5 plugins aren't compatible
    with Qt4/KDE4.
  * Now, Webcamoid can be compiled using MinGW.
  * Added webcam capture support through DirectShow.
  * There are still some patches needed to make it fully work
    in Windows.
  5.0.0:
  * Modified the effects preview for reducing resources usage.
  * Fixed stream flush on recording stop.
  * Enhanced webm video recording.
  5.0.0rc1:
  * Release Candidate version.
  * Ported to Qt5 (without the plasmoid).
  * Removed KDElibs as dependency, but still required for
    Qt4 build.
  * Removed QImageBlitz as dependency.
  * Added more effects.
  * Fixed video sync.
  * Initial port to Windows (help needed).
- Switched to Qt5
- Switched to ffmpeg 3.0
- Spec cleanup
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Mon Feb 10 2014 mailaender@opensuse.org
- Update to version 5.0.0b2
* Fri May  3 2013 fa0sck@gmail.com
- spec for openSUSE build changes:
  + Installpath all lowercase (patch)
  + Install under kde4_appsdir
  + generate help file
  + refresh translations
  + actually register plasmoid inside kde4_servicesdir
  + fix categories for desktop file
* Sun Oct 14 2012 mailaender@opensuse.org
- initial packaging
